# Ensemble Tools [![Documentation Status](https://readthedocs.org/projects/enstools/badge/?version=latest)](https://enstools.readthedocs.io/en/latest/?badge=latest)

This package provides core functionality to Python-based tools developed within
the framework of [Waves to Weather - Transregional Collaborative Research 
Project (SFB/TRR165)](https://wavestoweather.de). 

Shared functionality includes:
- Clustering (`enstools.clustering`)
- Interpolation (`enstools.interpolation`)
- Reading and Writing data (`enstools.io`)
- Retrieval of open data (`enstools.opendata`)
- Post-processing (`enstools.post`)
- Scores (`enstools.scores`)

# Installation

`pip` is the easiest way to install `enstools` along with all dependencies.

    pip install enstools



# Documentation

Explore [our documentation](https://enstools.readthedocs.io).     

# Acknowledgment and license

Ensemble Tools (`enstools`) is a collaborative development within
Waves to Weather (SFB/TRR165) coordinated by the subproject 
[Z2](https://www.wavestoweather.de/research_areas/phase2/z2) and funded by the
German Research Foundation (DFG).

A full list of code contributors can [CONTRIBUTORS.md](./CONTRIBUTORS.md).

The code is released under an [Apache-2.0 licence](./LICENSE).
